import { getLogout } from '@api/auth'
import solidLogo from '@assets/solid.svg'
import { useSiteContext } from '@context/SiteContext'
import useLanguage from '@hooks/useLanguage'
import {
  Avatar,
  AvatarBadge,
  Button,
  Flex,
  Spacer,
  Text,
  notificationService,
} from '@hope-ui/solid'
import { A, useNavigate } from '@solidjs/router'
import { Helpers } from '@utils/helper'
import { Show } from 'solid-js'
import { css } from 'solid-styled-components'

export default function Header() {
  const { store, setAuth } = useSiteContext()
  const navigate = useNavigate()
  const language = useLanguage()

  const logOut = async () => {
    try {
      await getLogout()
      Helpers.clearCookie()
      setAuth({ auth: false, user: null })
      navigate('/login', { replace: false })
    } catch (error) {
      notificationService.show({
        status: 'danger',
        title: 'Logout fail!',
        closable: false,
      })
    }
  }

  return (
    <header
      class={css`
        width: 100%;
      `}
    >
      <Flex bgColor="$success7" p="$3">
        <A href="/">
          <img
            src={solidLogo}
            class={css`
              width: 30px;
            `}
            alt="Solid logo"
          />
        </A>
        <Spacer />
        <Flex alignItems="center">
          <Show when={store.auth}>
            <Avatar name={store.userInfo?.name} size="sm">
              <AvatarBadge boxSize="1.25em" bg="$success9" />
            </Avatar>
            <Text size="sm" ml="$2" mr="$5" color="white">
              {store.userInfo?.name}
            </Text>
            <Button
              size="sm"
              variant="subtle"
              colorScheme="info"
              onClick={logOut}
            >
              {language.ui.logout}
            </Button>
          </Show>
        </Flex>
      </Flex>
    </header>
  )
}
