from uuid import uuid4
from sqlalchemy import Boolean, ForeignKey, String
from sqlalchemy.orm import Mapped, mapped_column, relationship

from sqlalchemy.dialects.postgresql import UUID

from .._model_base import SqlAlchemyBase

class User(SqlAlchemyBase):
  __tablename__ = 'users'

  id: Mapped[UUID] = mapped_column(UUID, primary_key=True, default=uuid4, index=True)
  username: Mapped[str | None] = mapped_column(String, unique=True, index=True, nullable=False)
  password: Mapped[str | None] = mapped_column(String, index=True, nullable=False)
  name: Mapped[str | None] = mapped_column(String, index=True, nullable=True)
  is_admin: Mapped[bool | None] = mapped_column(Boolean, default=False)
  is_lock: Mapped[bool | None] = mapped_column(Boolean, default=False)

  session_login = relationship("SessionLogin", back_populates="user", uselist=False)

  def __repr__(self):
    return f"{self.__class__.__name__}, name: {self.name}, username: {self.username}"

class SessionLogin(SqlAlchemyBase):
  __tablename__ = 'session_login'

  id: Mapped[int] = mapped_column(primary_key=True, autoincrement=True)
  session: Mapped[str] = mapped_column(String, unique=True, index=True, nullable=False)
  user_id: Mapped[str] = mapped_column(ForeignKey("users.id"), unique=True, index=True, nullable=False)

  user = relationship("User", back_populates="session_login")

  def __repr__(self):
    return f"{self.__class__.__name__}, session: {self.session}, user_id: {self.user_id}"
